This is an automated email from the ASF dual-hosted git repository.

spetz pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/iggy.git


The following commit(s) were added to refs/heads/master by this push:
     new 25e9d44dd fix(go): update MaxPayloadSize from 10 MB to 64 MB to match 
size update in rust message construction (#4080)
25e9d44dd is described below

commit 25e9d44dde95372d0f3e48011eb05aa3251410ed
Author: sipher <[email protected]>
AuthorDate: Mon Sep 7 03:16:07 2026 +0530

    fix(go): update MaxPayloadSize from 10 MB to 64 MB to match size update in 
rust message construction (#4080)
    
    Closes #4078
---
 foreign/go/contracts/messages.go | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/foreign/go/contracts/messages.go b/foreign/go/contracts/messages.go
index 4dc3d14a5..faa64508e 100644
--- a/foreign/go/contracts/messages.go
+++ b/foreign/go/contracts/messages.go
@@ -30,8 +30,8 @@ const (
        //
        //  Constraints
        //  - Minimum payload size: 1 byte (empty payloads are not allowed)
-       //  - Maximum payload size: 10 MB
-       MaxPayloadSize = 10 * 1000 * 1000
+       //  - Maximum payload size: 64 MB
+       MaxPayloadSize = 64 * 1000 * 1000
 
        // MaxUserHeadersSize is maximum allowed size in bytes for user-defined 
headers.
        //

Reply via email to